@@ -4,7 +4,7 @@ See http://www.djangoproject.com/ and https://cybernetics.hudora.biz/projects/wi
 """
 
 import datetime
-from django.contrib.admin.models import LogEntry
+from django.contrib.admin.models import LogEntry, ADDITION, CHANGE, DELETION
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.utils.encoding import smart_unicode
@@ -97,21 +97,29 @@ def log_action(obj, action, user=None, message='', reprstr=None):
     Arguments
      * obj: The object which is influenced by this action
      * action: one of the actions in django.contrib.admin.models; ADDITION, CHANGE, DELETION
+               or the string representation
      * user: the user which is responsible for this action. Defaults to user 'logger'
      * message: A short message containing information about the action
      * reprstr: a representation of the object
-
     """
     # from https://svn.python.org/conference/django/trunk/pycon/propmgr/changelog.py
-    content_t = ContentType.objects.get_for_model(type(obj))
+    
+    actions = {'ADDITION': ADDITION, 'CHANGE': CHANGE, 'DELETION': DELETION}
+    if isinstance(action, basestring):
+        action = actions[action]
+    
+    content_type = ContentType.objects.get_for_model(type(obj))
     if user is None:
-        log_user = User.objects.get(username='logger')
-        uid = log_user.id
+        try:
+            log_user = User.objects.get(username='logger')
+            uid = log_user.id
+        except User.DoesNotExist:
+            uid = 1
     else:
         uid = user.id
-
-    if reprstr == None:
+    
+    if reprstr is None:
         reprstr = smart_unicode(repr(obj))
     else:
         reprstr = smart_unicode(reprstr)
-    LogEntry.objects.log_action(uid, content_t.id, obj.id, reprstr, action, message)
+    LogEntry.objects.log_action(uid, content_type.id, obj.id, reprstr, action, message)
